==> zio-aws-ec2_2.12-5.17.128.1-sources.jar: zio/aws/ec2/model/DisassociateSubnetCidrBlockResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DisassociateSubnetCidrBlockResponse(
    ipv6CidrBlockAssociation: Option[
      zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation
    ] = None,
    subnetId: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse = {
    import DisassociateSubnetCidrBlockResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
      .builder()
      .optionallyWith(
        ipv6CidrBlockAssociation.map(value => value.buildAwsValue())
      )(_.ipv6CidrBlockAssociation)
      .optionallyWith(subnetId.map(value => value: java.lang.String))(
        _.subnetId
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly =
    zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.wrap(buildAwsValue())
}
object DisassociateSubnetCidrBlockResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse =
      zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse(
        ipv6CidrBlockAssociation.map(value => value.asEditable),
        subnetId.map(value => value)
      )
    def ipv6CidrBlockAssociation
        : Option[zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly]
    def subnetId: Option[String]
    def getIpv6CidrBlockAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "ipv6CidrBlockAssociation",
      ipv6CidrBlockAssociation
    )
    def getSubnetId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("subnetId", subnetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ) extends zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly {
    override val ipv6CidrBlockAssociation
        : Option[zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly] =
      scala
        .Option(impl.ipv6CidrBlockAssociation())
        .map(value =>
          zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.wrap(value)
        )
    override val subnetId: Option[String] =
      scala.Option(impl.subnetId()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ): zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.47.1-sources.jar: zio/aws/ec2/model/DisassociateSubnetCidrBlockResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DisassociateSubnetCidrBlockResponse(
    ipv6CidrBlockAssociation: Optional[
      zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation
    ] = Optional.Absent,
    subnetId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse = {
    import DisassociateSubnetCidrBlockResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
      .builder()
      .optionallyWith(
        ipv6CidrBlockAssociation.map(value => value.buildAwsValue())
      )(_.ipv6CidrBlockAssociation)
      .optionallyWith(subnetId.map(value => value: java.lang.String))(
        _.subnetId
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly =
    zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.wrap(buildAwsValue())
}
object DisassociateSubnetCidrBlockResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse =
      zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse(
        ipv6CidrBlockAssociation.map(value => value.asEditable),
        subnetId.map(value => value)
      )
    def ipv6CidrBlockAssociation
        : Optional[zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly]
    def subnetId: Optional[String]
    def getIpv6CidrBlockAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "ipv6CidrBlockAssociation",
      ipv6CidrBlockAssociation
    )
    def getSubnetId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("subnetId", subnetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ) extends zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly {
    override val ipv6CidrBlockAssociation
        : Optional[zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipv6CidrBlockAssociation())
        .map(value =>
          zio.aws.ec2.model.SubnetIpv6CidrBlockAssociation.wrap(value)
        )
    override val subnetId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DisassociateSubnetCidrBlockResponse
  ): zio.aws.ec2.model.DisassociateSubnetCidrBlockResponse.ReadOnly =
    new Wrapper(impl)
}
